@@ -7,6 +7,9 @@ import asyncio
 import typing
 from typing import ClassVar, Dict, Iterable, List, Union, overload
 
+from example2 import B
+
+
 max_rating: int = 10
 
 is_valid: bool
@@ -36,6 +39,10 @@ def f2(not_yet_a: "A") -> int:
     ...
 
 
+def f3(imported: B) -> B:
+    ...
+
+
 @overload
 def overloaded_func(a: float) -> float:
     ...
@@ -119,6 +126,19 @@ class A:
         return a * 2
 
 
+class C:
+    @overload
+    def __init__(self, a: int) -> None:
+        ...
+
+    @typing.overload
+    def __init__(self, a: float) -> None:
+        ...
+
+    def __init__(self, a: str):
+        ...
+
+
 async def async_function(wait: bool) -> int:
     """Blah.
 
