@@ -163,6 +163,14 @@ class TestPy3Module(object):
     def built(self, builder):
         builder("py3example")
 
+    def test_integration(self):
+        example_path = "_build/text/autoapi/example/index.txt"
+        with io.open(example_path, encoding="utf8") as example_handle:
+            example_file = example_handle.read()
+
+        assert "Initialize self" not in example_file
+        assert "a new type" not in example_file
+
     def test_annotations(self):
         example_path = "_build/text/autoapi/example/index.txt"
         with io.open(example_path, encoding="utf8") as example_handle:
@@ -182,6 +190,9 @@ class TestPy3Module(object):
         assert "List[Union[str, int]]" in example_file
 
         assert "not_yet_a: A" in example_file
+        assert "imported: example2.B" in example_file
+        assert "-> example2.B" in example_file
+
         assert "is_an_a" in example_file
         assert "ClassVar" in example_file
 
@@ -216,6 +227,13 @@ class TestPy3Module(object):
         assert "undoc_overloaded_func" in example_file
         assert "undoc_overloaded_method" in example_file
 
+        assert "C(a: int" in example_file
+        assert "C(a: float" in example_file
+        assert "C(a: str" not in example_file
+        assert "C(self, a: int" not in example_file
+        assert "C(self, a: float" not in example_file
+        assert "C(self, a: str" not in example_file
+
     def test_async(self):
         example_path = "_build/text/autoapi/example/index.txt"
         with io.open(example_path, encoding="utf8") as example_handle:
